==> webkit2gtk_2.42.2.orig.tar.xz: webkitgtk-2.42.2/Source/WebCore/rendering/style/StyleNamedImage.cpp <==
/*
 * Copyright (C) 2022 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include "config.h"
#include "StyleNamedImage.h"

#include "CSSNamedImageValue.h"
#include "NamedImageGeneratedImage.h"

namespace WebCore {

StyleNamedImage::StyleNamedImage(String&& name)
    : StyleGeneratedImage { Type::NamedImage, StyleNamedImage::isFixedSize }
    , m_name { WTFMove(name) }
{
}

StyleNamedImage::~StyleNamedImage() = default;

bool StyleNamedImage::operator==(const StyleImage& other) const
{
    return is<StyleNamedImage>(other) && equals(downcast<StyleNamedImage>(other));
}

bool StyleNamedImage::equals(const StyleNamedImage& other) const
{
    return m_name == other.m_name;
}

Ref<CSSValue> StyleNamedImage::computedStyleValue(const RenderStyle&) const
{
    return CSSNamedImageValue::create(m_name);
}

bool StyleNamedImage::isPending() const
{
    return false;
}

void StyleNamedImage::load(CachedResourceLoader&, const ResourceLoaderOptions&)
{
}

RefPtr<Image> StyleNamedImage::image(const RenderElement* renderer, const FloatSize& size) const
{
    if (!renderer)
        return &Image::nullImage();

    if (size.isEmpty())
        return nullptr;

    return NamedImageGeneratedImage::create(m_name, size);
}

bool StyleNamedImage::knownToBeOpaque(const RenderElement&) const
{
    return false;
}

FloatSize StyleNamedImage::fixedSize(const RenderElement&) const
{
    return { };
}

} // namespace WebCore

==> webkit2gtk_2.43.3.orig.tar.xz: webkitgtk-2.43.3/Source/WebCore/rendering/style/StyleNamedImage.cpp <==
/*
 * Copyright (C) 2022 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include "config.h"
#include "StyleNamedImage.h"

#include "CSSNamedImageValue.h"
#include "NamedImageGeneratedImage.h"

namespace WebCore {

StyleNamedImage::StyleNamedImage(String&& name)
    : StyleGeneratedImage { Type::NamedImage, StyleNamedImage::isFixedSize }
    , m_name { WTFMove(name) }
{
}

StyleNamedImage::~StyleNamedImage() = default;

bool StyleNamedImage::operator==(const StyleImage& other) const
{
    return is<StyleNamedImage>(other) && equals(downcast<StyleNamedImage>(other));
}

bool StyleNamedImage::equals(const StyleNamedImage& other) const
{
    return m_name == other.m_name;
}

Ref<CSSValue> StyleNamedImage::computedStyleValue(const RenderStyle&) const
{
    return CSSNamedImageValue::create(m_name);
}

bool StyleNamedImage::isPending() const
{
    return false;
}

void StyleNamedImage::load(CachedResourceLoader&, const ResourceLoaderOptions&)
{
}

RefPtr<Image> StyleNamedImage::image(const RenderElement* renderer, const FloatSize& size, bool) const
{
    if (!renderer)
        return &Image::nullImage();

    if (size.isEmpty())
        return nullptr;

    return NamedImageGeneratedImage::create(m_name, size);
}

bool StyleNamedImage::knownToBeOpaque(const RenderElement&) const
{
    return false;
}

FloatSize StyleNamedImage::fixedSize(const RenderElement&) const
{
    return { };
}

} // namespace WebCore
